% GETSTRUCTDATA.M will extract selected data variables from a struct, and
% clean up the workspace when done.  This was adapted from LOADLOGDATA.M,
% which was written to manipulate log data from the RiSE robot logger.
% This function should be called by VIDSYNC_Rxx.M once the data has been
% loaded.
% A. McClung - 05/10/05 - Stanford University

%Make sure the file contains a 'data' structure
if isstruct(data2sync.data)==0
    error(['NOTE: ''data'' structure is not in ''' aname '''.'])
end
data=data2sync.data;
%Get the data fields
fieldlist=fieldnames(data);
varlist=[];
for i=1:size(fieldlist,1)
    %Create variable name and place data within by converting the cell name to single matrix
    eval([cell2mat(fieldlist(i,:)) '=[data.' cell2mat(fieldlist(i,:)) ']'';'])
    varlist=[varlist ',fieldlist(' num2str(i) ',:)'];
end
%Determine the approximate sampling rate
datatime=time;                      %Copy the time data to another variable
gapsum=0;
for i=1:size(datatime,1)-1
    gapsum=gapsum+datatime(i+1)-datatime(i);
end
datasamp=size(datatime,1)/gapsum;    % Approximate sampling rate
%Select fields to plot
%% Create string to make a menu of variables
prefix=['field2plot=menu(''Variables found other than time'''];
suffix=[');'];
evalstring=[prefix varlist suffix];
eval(evalstring);
fieldname=cell2mat(fieldlist(field2plot,:));    %Get a simple name for the selected field data
data2sync=eval(fieldname);                      %Place the selected field data in a convenient variable
%Plot the fields
flld=figure;            % Figure Load Log Data (FLLD)
plot(time,data2sync)
%Format the plot
title(['Time vs ' fieldname ' (All columns)'])
xlabel('Time (s)')
ylabel([fieldname ' units'])
%Add a legend for all columns of data
prefix=['legend(''1'''];
suffix=[')'];
varlist=[];
for i=2:size(data2sync,2)
    varlist=[varlist ',''' num2str(i) ''''];
end
evalstring=[prefix varlist suffix];
eval(evalstring)

%Select the columns for video and data syncronizing
datacols=input('Please select columns to use for video sync {eg. [1 2 3]) : ');

%Cleanup the workspace
close(flld)
for i=1:size(fieldlist,1)
    eval(['clear ' cell2mat(fieldlist(i,:))])
end
clear data fieldlist varlist prefix suffix evalstring field2plot
clear fieldname flld gapsum i

